<?php

namespace Drupal\optimizely\Tests;

use Drupal\Core\Language\LanguageInterface;
use Drupal\Tests\BrowserTestBase;

/**
 * Test enabling / disabling non-default project from update page.
 *
 * @group Optimizely
 */
class OptimizelyEnableDisableTest extends BrowserTestBase {

  protected $defaultTheme = 'stark';
  protected $addUpdatePage = 'admin/config/system/optimizely/add_update';
  protected $update2Page = 'admin/config/system/optimizely/add_update/2';
  protected $addAliasPage = 'admin/config/search/path/add';

  protected $privilegedUser;

  protected $optimizelyPermission = 'administer optimizely';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['optimizely', 'node', 'path'];

  /**
   * {@inheritdoc}
   */
  public static function getInfo() {
    return [
      'name' => 'Optimizely Enable / Disable Project',
      'description' => 'Test enabling / disabling non-default projects.',
      'group' => 'Optimizely',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {

    parent::setUp();

    $this->drupalCreateContentType(['type' => 'page', 'name' => 'Basic page']);

    $this->privilegedUser = $this->drupalCreateUser([
      'access content',
      'create page content',
      'administer url aliases',
      'create url aliases',
      $this->optimizelyPermission,
    ]);
  }

  /**
   * Test enabling and disable on the project update page.
   */
  public function testEnableDisable() {

    $this->drupalLogin($this->privilegedUser);

    // ----- create page.
    $settings = [
      'type' => 'page',
      'title' => $this->randomMachineName(32),
      'langcode' => LanguageInterface::LANGCODE_NOT_SPECIFIED,
      'body' => [
                  [
                    'value' => $this->randomMachineName(64),
                    'format' => filter_default_format(),
                  ],
      ],
    ];
    $node = $this->drupalCreateNode($settings);

    // Create the url alias
    // N.B. The source and alias paths MUST start with a leading slash.
    $edit_node = [];
    $edit_node['path'] = '/node/' . $node->id();
    $edit_node['alias'] = '/' . $this->randomMachineName(10);
    $this->drupalGet($this->addAliasPage);
    $this->submitForm($edit_node, 'Save');

    // Add a project with a path to the alias.
    $edit = [
      'optimizely_project_title' => $this->randomMachineName(8),
      'optimizely_project_code' => mt_rand(0, 10000),
      'optimizely_path' => $edit_node['alias'],
      'optimizely_enabled' => 0,
    ];
    $this->drupalGet($this->addUpdatePage);
    $this->submitForm($edit, 'Add');

    $edit_2 = [
      'optimizely_enabled' => 1,
    ];
    $this->drupalGet($this->update2Page);
    $this->submitForm($edit_2, 'Update');

    // Test if project was enabled.
    $enabled = \Drupal::database()->query('SELECT enabled FROM {optimizely} WHERE oid = 2')->fetchField();
    $this->assertEquals($enabled, $edit_2['optimizely_enabled']);

    $edit_3 = [
      'optimizely_enabled' => 0,
    ];
    $this->drupalGet($this->update2Page);
    $this->submitForm($edit_3, 'Update');

    // Test if project was disabled.
    $enabled = \Drupal::database()->query('SELECT enabled FROM {optimizely} WHERE oid = 2')->fetchField();
    $this->assertEquals($enabled, $edit_3['optimizely_enabled']);

  }

}
